@@ -4,9 +4,10 @@ use common::sense;
 use aliased 'Squatting::H';
 use Data::Page;
 use Rhetoric::Formatters;
+use IO::All;
 
 our $F = $Rhetoric::Formatters::F;
-our @EXPORT_OK   = qw(now slug $F);
+our @EXPORT_OK   = qw(now slug rl wl file_owner $F);
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 # y m d h m s
@@ -32,4 +33,23 @@ sub slug {
   return $title;
 }
 
+# read line
+sub rl {
+  my $file = shift;
+  io($file)->chomp->getline();
+}
+
+# write line
+sub wl {
+  my $file = shift;
+  my $line = shift;
+  io($file) < "$line\n";
+}
+
+# owner of file
+sub file_owner {
+  my $file = shift;
+  getpwuid( (stat($file))[4] );
+}
+
 1;
